@@ -52,6 +52,14 @@ class LeetcodeWrapper:
         Returns:
             dict: The user's profile data.
         """
+        return self._request(f"/{self.username}")
+
+    def get_full_profile(self):
+        """Fetches the user's full profile details.
+
+        Returns:
+            dict: The user's full profile data.
+        """
         return self._request(f"/userProfile/{self.username}")
 
     def get_badges(self):
